library(psych)
library(sampleSelection)
library(stargazer)
library(censReg)
library(mvtnorm)

####################### Simulation Example no 1. ##############################
  # Exclusion restriction

rm(list=ls())
set.seed(1234567) # setting seed

alpha <- 0.2 # When alpha is small there is basically no exclusion restriction
x1 <- rnorm(1000,0,2)
x2 <- rnorm(1000,0,1)
x3 <- rnorm(1000,0,1)

sigma <- matrix(c(1,1.5,1.5,4), ncol=2)
eps <- rmvnorm(n=1000, mean=c(0,0), sigma=sigma)

y1star <- -1 - 0.5*x1 + 1*x2 + alpha*x3 + eps[,1]
y1 <- y1star > 0
summary(y1)

y2<- 6+x1 + 0.5*x2 + eps[,2]
y2[y1 == 0] <- 0
hist(y2)
summary(y2)

Eq1 <- y2 ~ x1 + x2
Eq2 <- y1 ~ x1 + x2 + x3 # selection

model1 <- selection(Eq2, Eq1, method="2step")
summary(model1)

model1b <- selection(Eq2, Eq1, method="ml")
summary(model1b)

# model1c <- lm(Eq1, subset = y2 > 0)
# summary(model1c)
